function [Pot,rend,Wrev,WI,Wroz,Wq,W,Q23,Q41,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2,gb,gu,T3]=OTTOTTF(rfuel,n,r)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% PARAMETROS DE SALIDA
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%	Pot	Potencia de salida.
%%	rend	Rendimiento.
%%	Wrev	Trabajo reversible del ciclo.
%%	WI	Trabajo considerando irreversibilidades internas.
%%	Wroz	Trabajo de las fuerzas de rozamiento.
%%	Wq	Trabajo perdido debido a las pérdidas de calor.
%%	W	Trabajo del ciclo.
%%	Q23	Calor de entrada del ciclo.
%%	Q41	Calor de salida del ciclo.
%%	fmXX	Fracción másica de XX
%%	gu	Índice politrópico de los gases sin quemar.
%%	gb	Índice politrópico de los gases quemados.
%%	T3	Máxima temperatura del ciclo.
%%	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% DATOS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%	Geométricos:
%%
%%	d	Diámetro del pistón
%%	x	Altura del volumen muerto	
%%	r	Relación de compresión
%%	l	Largo de la biela
%%
%%
%%	Funcionamiento:
%%
%%	Tp	Temperatura de la pared del cilindro
%%	T1	Temperatura de la mezcla fresca en el punto muerto inferior
%%	n	Velocidad de giro
%%	m	masa de gas dentro del cilindro
%%
%%	Combustible: ISO-OCTANO
%%
%%	rfuel	Relación de equivalencia de combustible y aire (F/A)/(F/A)q
%%	rq	Relación de equivalencia de combustible y aire estequiométrica
%%	qvi	Poder calorífico inferior a volumen constante
%%	mmolf	Masa molar del ISO-OCTANO
%%
%%
%%	Parámetros para el cálculo de irreversibilidades:
%%
%%	e	Coeficiente de relación entre calor perdido y trabajo perdido
%%	IR	Coeficiente de irreversibilidades interna
%%	C	Coeficiente de transferencia de calor convectivo
%%	mu	Coeficiente de fricción
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%% INICIO DE PARÁMETROS DE SIMULACIÓN %%%%%%%%%%
Tol_Temp=1e-4;
mmolAir=28.9651159e-3;
mmolCO2=44.0095e-3;
mmolCO=28.0101e-3;
mmolH2=2.01588e-3;
mmolH2O=18.01528e-3;
mmolO2=31.9988e-3;
mmolN2=28.1610e-3;
R=8.314472e0;
%%%%%%%%%% FIN DE PARÁMETROS DE SIMULACIÓN %%%%%%%%%%

%%%%%%%%%% INICIO DE DATOS DEL PROBLEMA %%%%%%%%%%
%%DATOS GEOMETRICOS%%
d=70.0e-3;
x=5.9e-3;
l=150.0e-3;

%%DATOS DE ENTRADA%%
Tp=600;
T1=330;
m=2.77e-4;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Masa variable con la velocidad de giro
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% m=3.1855e-4-0.00031855e-4*n;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%DATOS DEL COMBUSTIBLE%%
rq=0.0683;
qvi=5109178.0e0;
mmolf=114.22852e-3;

%%PARÁMETROS DE MODELOS DE IRREVERSIBILIDAD%%
e=0.1;
IR=1.2;
C=1300;
mu=10;
%%%%%%%%%% FIN DE DATOS DEL PROBLEMA %%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Con la velocidad de giro calculamos el tiempo del ciclo
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
t=120./n;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Con el diámetro del pistón calculamos el área del pistón (Ap),
%% con la distancia mínima se calcula el volúmen mínimo (V0), con el volumen 
%% mínimo, el área del pistón y la relación de compresión se calcula la carrera
%% y con la carrera el volumen máximo desplazado (Vd)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Ap=pi.*d.^2./4;
V0=x.*Ap;
a=V0.*(r-1)./(2.*Ap);
Vd=2.*a.*Ap;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Con la relación de combustible aire calculamos las fracciones de fuel y aire
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
xf=rfuel*rq/(rfuel*rq+1.0);
xa=1/(rfuel*rq+1.0);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Iteramos para obtener gu. Procedemos de la siguiente forma:
%%------------------------------------------------------------------------------
%% 1. Supongo el índice politrópico promedio gu=1.3 para comenzar la iteración
%% 2. Calulamos T2
%% 3. Con T2 y T1 calculamos los cp y cv promedios de los gases sin quemar
%% 4. Con los cp y cv promedios calculamos el gu promedio 
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
gu=1.3;
T2=T1.*(r.^(gu-1));
cpu_medio=(cpu(T1,xf,xa)+cpu(T2,xf,xa))/2;
cvu_medio=(cvu(T1,xf,xa)+cvu(T2,xf,xa))/2;
gu=cpu_medio/cvu_medio;
while abs(T2-T1.*(r.^(gu-1)))>Tol_Temp
T2=T1.*(r.^(gu-1));
cpu_medio=(cpu(T1,xf,xa)+cpu(T2,xf,xa))/2;
cvu_medio=(cvu(T1,xf,xa)+cvu(T2,xf,xa))/2;
gu=cpu_medio/cvu_medio;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Con gu calculamos T2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
T2=T1.*(r.^(gu-1));


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Con T2 calculamos T3 a partir de la temperatura adiabática de llama
%%
%% Iteramos para obtener T3. Procedemos de la siguiente forma:
%%------------------------------------------------------------------------------
%% 1. Supongo T3=3000 para comenzar la iteración
%% 2. Calulamos los productos de combustión a la temperatura de equilibrio T3
%% 3. Con los productos de la combustión recalculamos la tempreatura de llama T3
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
T3=3000;
[fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2,Rb,mmolarRes]=productos(T3,rfuel);
while abs(T3-tadll(T2,xf,xa,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2))>Tol_Temp
T3=tadll(T2,xf,xa,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2);
[fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2,Rb,mmolarRes]=productos(T3,rfuel);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Iteramos para obtener gb. Procedemos de la siguiente forma:
%%------------------------------------------------------------------------------
%% 1. Supongo el índice politrópico promedio gb=1.2 para comenzar la iteración
%% 2. Calulamos T4
%% 3. Con T4 y T3 calculamos los cp y cv promedios de los gases quemados
%% 4. Con los cp y cv promedios calculamos el gb promedio 
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
gb=1.2;
T4=T3.*(r.^(1-gb));
cpb_medio=(cpb(T3,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2)+cpb(T4,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2))/2;
cvb_medio=(cvb(T3,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2)+cvb(T4,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2))/2;
gb=cpb_medio/cvb_medio;
while abs(T4-T3.*(r.^(1-gb)))>Tol_Temp
T4=T3.*(r.^(1-gb));
cpb_medio=(cpb(T3,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2)+cpb(T4,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2))/2;
cvb_medio=(cvb(T3,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2)+cvb(T4,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2))/2;
gb=cpb_medio/cvb_medio;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Con gb calculamos T4
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
T4=T3.*(r.^(1-gb));


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Hay dos maneras de calcular los calores de entrada y salida del ciclo:
%%
%%	1. A partrir de las energías internas en cada estado del ciclo 
%%	2. Calculando una capacidad calorífica promedio y utilizando Q=m*cv*DT
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Primera forma:
%%	
%% Con T1, T2, T3 y T4 calculamos los aportes y las salidas de calor del ciclo
%% a partir de las energías internas sensibles de los gases.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Q23=m*(ubs(T3,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2)-uus(T2,xf,xa));
%% Q41=m*(ubs(T4,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2)-uus(T1,xf,xa));
%% Wrev=Q23-Q41;
%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Segunda forma:
%%	
%% Con T1, T2, T3 y T4 calculamos las capacidades caloríficas promedio
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 tau=T1/T3;
 CV23_medio=m*(cvu(T2,xf,xa)+cvb(T3,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2))./2;
 CV41_medio=m*(cvb(T1,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2)+cvb(T4,fmCO2,fmCO,fmH2,fmH2O,fmO2,fmN2))./2;

 Q23=T3.*(CV23_medio.*(1-tau.*r.^(gu-1)));
 Q41=T3.*(CV41_medio.*(r.^(1-gb)-tau));
 
 Wrev=Q23-Q41;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Con los calores de entrada y salida del ciclo calculamos el TRABAJO 
%% considerando irreversibilidades internas.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
WI=Q23-IR*Q41;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% A partir de los parámetros geométricos y la velocidad de giro calculamos 
%% el TRABAJO de las fuerzas de rozamiento.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f=a/l;
xi2= @(x) (sin(x)+f*sin(x)*cos(x)/sqrt(1-f^2*sin(x)^2))^2;
Int=quad(xi2,0,4*pi);

Wroz=a.*mu.*(n.*2.*pi./60).*V0.*(r-1)./(2.*Ap).*Int;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Formula para estimar el trabajo de las fuerzas de rozamiento a partir  
%% de la fórmula empírica de Barness y Moss
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Wroz=(Vd/4)*(97000+15000*(n/1000)+5000*(n/1000)^2);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% A partir de los parámetros geométricos, el tiempo del ciclo y algunas 
%% temperaturas calculamos el TRABAJO de perdido debido a la transferencia 
%% de calor.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Wq=(1./16).*e.*pi.*d.*C.*t.*T3.*(d+x.*(1+r)).*(1+r.^(1-gb)-2.*Tp./T3);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Con los diferentes trabajos, el calor de entrada al ciclo y el tiempo
%% calculamos la Potencia y el Rendimiento.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
W=abs(WI)-abs(Wroz)-abs(Wq);
Pot=W/t;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Rendimiento de conversión de combustible
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Q23=(qvi/mmolf*m*xf);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
rend=W/Q23;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Descomentar estas líneas para ver el diagrama p-V.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% V1=V0*r;
%% V4=V1;
%% V2=V0;
%% V3=V2;
%% Ru=R*(xf/mmolf+xa/mmolAir);
%% Rb=R*(fmCO2/mmolCO2+fmCO/mmolCO+fmH2/mmolH2+fmH2O/mmolH2O+fmO2/mmolO2+fmN2/mmolN2);
%% 
%% p1=m*Ru*T1/V1
%% p2=m*Ru*T2/V2
%% p3=m*Rb*T3/V3
%% p4=m*Rb*T4/V4
%% 
%% va=(V1:(V2-V1)/50:V2);
%% vb=(V3:(V4-V3)/50:V4);
%% pa=p1.*(V1./va).^gu;
%% pb=p3.*(V3./vb).^gb;
%% plot(va,pa,vb,pb)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
